@@ -40,7 +40,5 @@ f"{{{{x}}}}"
 ""f""
 ''f""
 (""f""r"")
-
-# To be fixed
-# Error: f-string: single '}' is not allowed at line 41 column 8
-# f"\{{x}}"
+f"{v:{f"0.2f"}}"
+f"\{{x}}"
