@@ -1,9 +1,9 @@
 use crate::registry::Rule;
 use ruff_macros::CacheKey;
-use std::fmt::{Debug, Formatter};
+use std::fmt::{Debug, Display, Formatter};
 use std::iter::FusedIterator;
 
-const RULESET_SIZE: usize = 12;
+const RULESET_SIZE: usize = 13;
 
 /// A set of [`Rule`]s.
 ///
@@ -269,6 +269,21 @@ impl Debug for RuleSet {
     }
 }
 
+impl Display for RuleSet {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        if self.is_empty() {
+            write!(f, "[]")?;
+        } else {
+            writeln!(f, "[")?;
+            for rule in self {
+                writeln!(f, "\t{rule:?},")?;
+            }
+            write!(f, "]")?;
+        }
+        Ok(())
+    }
+}
+
 impl FromIterator<Rule> for RuleSet {
     fn from_iter<T: IntoIterator<Item = Rule>>(iter: T) -> Self {
         let mut set = RuleSet::empty();
