@@ -2,7 +2,7 @@ use ruff_python_ast::Expr;
 
 use ruff_diagnostics::{Diagnostic, Violation};
 use ruff_macros::{derive_message_formats, violation};
-use ruff_python_ast::call_path::from_qualified_name;
+use ruff_python_ast::name::QualifiedName;
 use ruff_text_size::Ranged;
 
 use crate::checkers::ast::Checker;
@@ -58,14 +58,18 @@ pub(crate) fn banned_api<T: Ranged>(checker: &mut Checker, policy: &NameMatchPol
 /// TID251
 pub(crate) fn banned_attribute_access(checker: &mut Checker, expr: &Expr) {
     let banned_api = &checker.settings.flake8_tidy_imports.banned_api;
+    if banned_api.is_empty() {
+        return;
+    }
+
     if let Some((banned_path, ban)) =
         checker
             .semantic()
-            .resolve_call_path(expr)
-            .and_then(|call_path| {
-                banned_api
-                    .iter()
-                    .find(|(banned_path, ..)| call_path == from_qualified_name(banned_path))
+            .resolve_qualified_name(expr)
+            .and_then(|qualified_name| {
+                banned_api.iter().find(|(banned_path, ..)| {
+                    qualified_name == QualifiedName::from_dotted_name(banned_path)
+                })
             })
     {
         checker.diagnostics.push(Diagnostic::new(
