@@ -72,7 +72,8 @@ fn build_fstring(joiner: &str, joinees: &[Expr]) -> Option<Expr> {
                         None
                     }
                 })
-                .join(joiner),
+                .join(joiner)
+                .into_boxed_str(),
             ..ast::StringLiteral::default()
         };
         return Some(node.into());
@@ -115,7 +116,7 @@ pub(crate) fn static_join_to_fstring(checker: &mut Checker, expr: &Expr, joiner:
     if !keywords.is_empty() {
         return;
     }
-    let [arg] = args.as_slice() else {
+    let [arg] = &**args else {
         return;
     };
 
