@@ -67,6 +67,7 @@ pub struct Settings {
     pub lines_between_types: usize,
     pub forced_separate: Vec<String>,
     pub section_order: Vec<ImportSection>,
+    pub default_section: ImportSection,
     pub no_sections: bool,
     pub from_first: bool,
     pub length_sort: bool,
@@ -97,6 +98,7 @@ impl Default for Settings {
             lines_between_types: 0,
             forced_separate: Vec::new(),
             section_order: ImportType::iter().map(ImportSection::Known).collect(),
+            default_section: ImportSection::Known(ImportType::ThirdParty),
             no_sections: false,
             from_first: false,
             length_sort: false,
@@ -132,6 +134,7 @@ impl Display for Settings {
                 self.lines_between_types,
                 self.forced_separate | array,
                 self.section_order | array,
+                self.default_section,
                 self.no_sections,
                 self.from_first,
                 self.length_sort,
