@@ -67,14 +67,14 @@ pub(crate) fn invalid_escape_sequence(
     token_range: TextRange,
 ) {
     let (token_source_code, string_start_location) = match token {
-        Tok::FStringMiddle { value, is_raw } => {
+        Tok::FStringMiddle { value, is_raw, .. } => {
             if *is_raw {
                 return;
             }
             let Some(range) = indexer.fstring_ranges().innermost(token_range.start()) else {
                 return;
             };
-            (value.as_str(), range.start())
+            (&**value, range.start())
         }
         Tok::String { kind, .. } => {
             if kind.is_raw() {
