@@ -71,7 +71,7 @@ impl<'a> FormatSummaryValues<'a> {
         let mut extracted_args: Vec<&Expr> = Vec::new();
         let mut extracted_kwargs: FxHashMap<&str, &Expr> = FxHashMap::default();
 
-        for arg in &call.arguments.args {
+        for arg in call.arguments.args.iter() {
             if matches!(arg, Expr::Starred(..))
                 || contains_quotes(locator.slice(arg))
                 || locator.contains_line_break(arg.range())
@@ -80,7 +80,7 @@ impl<'a> FormatSummaryValues<'a> {
             }
             extracted_args.push(arg);
         }
-        for keyword in &call.arguments.keywords {
+        for keyword in call.arguments.keywords.iter() {
             let Keyword {
                 arg,
                 value,
@@ -146,9 +146,9 @@ fn parenthesize(expr: &Expr, text: &str, context: FormatContext) -> bool {
             Expr::BinOp(_)
             | Expr::UnaryOp(_)
             | Expr::BoolOp(_)
-            | Expr::NamedExpr(_)
+            | Expr::Named(_)
             | Expr::Compare(_)
-            | Expr::IfExp(_)
+            | Expr::If(_)
             | Expr::Lambda(_)
             | Expr::Await(_)
             | Expr::Yield(_)
@@ -166,7 +166,7 @@ fn parenthesize(expr: &Expr, text: &str, context: FormatContext) -> bool {
         // E.g., `{x, y}` should be parenthesized in `f"{(x, y)}"`.
         (
             _,
-            Expr::GeneratorExp(_)
+            Expr::Generator(_)
             | Expr::Dict(_)
             | Expr::Set(_)
             | Expr::SetComp(_)
@@ -175,7 +175,7 @@ fn parenthesize(expr: &Expr, text: &str, context: FormatContext) -> bool {
         (_, Expr::Subscript(ast::ExprSubscript { value, .. })) => {
             matches!(
                 value.as_ref(),
-                Expr::GeneratorExp(_)
+                Expr::Generator(_)
                     | Expr::Dict(_)
                     | Expr::Set(_)
                     | Expr::SetComp(_)
@@ -185,7 +185,7 @@ fn parenthesize(expr: &Expr, text: &str, context: FormatContext) -> bool {
         (_, Expr::Attribute(ast::ExprAttribute { value, .. })) => {
             matches!(
                 value.as_ref(),
-                Expr::GeneratorExp(_)
+                Expr::Generator(_)
                     | Expr::Dict(_)
                     | Expr::Set(_)
                     | Expr::SetComp(_)
@@ -195,7 +195,7 @@ fn parenthesize(expr: &Expr, text: &str, context: FormatContext) -> bool {
         (_, Expr::Call(ast::ExprCall { func, .. })) => {
             matches!(
                 func.as_ref(),
-                Expr::GeneratorExp(_)
+                Expr::Generator(_)
                     | Expr::Dict(_)
                     | Expr::Set(_)
                     | Expr::SetComp(_)
@@ -447,17 +447,6 @@ pub(crate) fn f_strings(
         contents.insert(0, ' ');
     }
 
-    // Avoid refactors that exceed the line length limit.
-    if !fits_or_shrinks(
-        &contents,
-        template.into(),
-        checker.locator(),
-        checker.settings.pycodestyle.max_line_length,
-        checker.settings.tab_size,
-    ) {
-        return;
-    }
-
     // Finally, avoid refactors that would introduce a runtime error.
     // For example, Django's `gettext` supports `format`-style arguments, but not f-strings.
     // See: https://docs.djangoproject.com/en/4.2/topics/i18n/translation
@@ -465,10 +454,10 @@ pub(crate) fn f_strings(
         expr.as_call_expr().is_some_and(|call| {
             checker
                 .semantic()
-                .resolve_call_path(call.func.as_ref())
-                .map_or(false, |call_path| {
+                .resolve_qualified_name(call.func.as_ref())
+                .map_or(false, |qualified_name| {
                     matches!(
-                        call_path.as_slice(),
+                        qualified_name.segments(),
                         ["django", "utils", "translation", "gettext" | "gettext_lazy"]
                     )
                 })
@@ -479,17 +468,27 @@ pub(crate) fn f_strings(
 
     let mut diagnostic = Diagnostic::new(FString, call.range());
 
+    // Avoid refactors that exceed the line length limit or make it exceed by more.
+    let f_string_fits_or_shrinks = fits_or_shrinks(
+        &contents,
+        template.into(),
+        checker.locator(),
+        checker.settings.pycodestyle.max_line_length,
+        checker.settings.tab_size,
+    );
+
     // Avoid fix if there are comments within the call:
     // ```
     // "{}".format(
     //     0,  # 0
     // )
     // ```
-    if !checker
+    let has_comments = checker
         .indexer()
         .comment_ranges()
-        .intersects(call.arguments.range())
-    {
+        .intersects(call.arguments.range());
+
+    if f_string_fits_or_shrinks && !has_comments {
         diagnostic.set_fix(Fix::safe_edit(Edit::range_replacement(
             contents,
             call.range(),
