@@ -1,18 +1,16 @@
 use std::cmp::Ordering;
 
+use ast::helpers::comment_indentation_after;
 use ruff_python_ast::whitespace::indentation;
-use ruff_python_ast::{
-    self as ast, AnyNodeRef, Comprehension, Expr, MatchCase, ModModule, Parameters,
-};
+use ruff_python_ast::{self as ast, AnyNodeRef, Comprehension, Expr, ModModule, Parameters};
 use ruff_python_trivia::{
     find_only_token_in_range, indentation_at_offset, BackwardsTokenizer, CommentRanges,
     SimpleToken, SimpleTokenKind, SimpleTokenizer,
 };
 use ruff_source_file::Locator;
-use ruff_text_size::{Ranged, TextLen, TextRange, TextSize};
+use ruff_text_size::{Ranged, TextLen, TextRange};
 
 use crate::comments::visitor::{CommentPlacement, DecoratedComment};
-use crate::expression::expr_generator_exp::is_generator_parenthesized;
 use crate::expression::expr_slice::{assign_comment_in_slice, ExprSliceCommentSection};
 use crate::other::parameters::{
     assign_argument_separator_comment_placement, find_parameter_separators,
@@ -229,14 +227,14 @@ fn handle_enclosed_comment<'a>(
             handle_pattern_keyword_comment(comment, pattern_keyword, locator)
         }
         AnyNodeRef::ExprUnaryOp(unary_op) => handle_unary_op_comment(comment, unary_op, locator),
-        AnyNodeRef::ExprNamedExpr(_) => handle_named_expr_comment(comment, locator),
+        AnyNodeRef::ExprNamed(_) => handle_named_expr_comment(comment, locator),
         AnyNodeRef::ExprLambda(lambda) => handle_lambda_comment(comment, lambda, locator),
         AnyNodeRef::ExprDict(_) => handle_dict_unpacking_comment(comment, locator)
             .or_else(|comment| handle_bracketed_end_of_line_comment(comment, locator))
             .or_else(|comment| handle_key_value_comment(comment, locator)),
         AnyNodeRef::ExprDictComp(_) => handle_key_value_comment(comment, locator)
             .or_else(|comment| handle_bracketed_end_of_line_comment(comment, locator)),
-        AnyNodeRef::ExprIfExp(expr_if) => handle_expr_if_comment(comment, expr_if, locator),
+        AnyNodeRef::ExprIf(expr_if) => handle_expr_if_comment(comment, expr_if, locator),
         AnyNodeRef::ExprSlice(expr_slice) => {
             handle_slice_comments(comment, expr_slice, comment_ranges, locator)
         }
@@ -289,16 +287,37 @@ fn handle_enclosed_comment<'a>(
             }
         }
         AnyNodeRef::FString(fstring) => CommentPlacement::dangling(fstring, comment),
+        AnyNodeRef::FStringExpressionElement(_) => {
+            // Handle comments after the format specifier (should be rare):
+            //
+            // ```python
+            // f"literal {
+            //     expr:.3f
+            //     # comment
+            // }"
+            // ```
+            //
+            // This is a valid comment placement.
+            if matches!(
+                comment.preceding_node(),
+                Some(
+                    AnyNodeRef::FStringExpressionElement(_) | AnyNodeRef::FStringLiteralElement(_)
+                )
+            ) {
+                CommentPlacement::trailing(comment.enclosing_node(), comment)
+            } else {
+                handle_bracketed_end_of_line_comment(comment, locator)
+            }
+        }
         AnyNodeRef::ExprList(_)
         | AnyNodeRef::ExprSet(_)
         | AnyNodeRef::ExprListComp(_)
         | AnyNodeRef::ExprSetComp(_) => handle_bracketed_end_of_line_comment(comment, locator),
-        AnyNodeRef::ExprTuple(tuple) if tuple.is_parenthesized(locator.contents()) => {
-            handle_bracketed_end_of_line_comment(comment, locator)
-        }
-        AnyNodeRef::ExprGeneratorExp(generator)
-            if is_generator_parenthesized(generator, locator.contents()) =>
-        {
+        AnyNodeRef::ExprTuple(ast::ExprTuple {
+            parenthesized: true,
+            ..
+        }) => handle_bracketed_end_of_line_comment(comment, locator),
+        AnyNodeRef::ExprGenerator(generator) if generator.parenthesized => {
             handle_bracketed_end_of_line_comment(comment, locator)
         }
         _ => CommentPlacement::Default(comment),
@@ -322,7 +341,7 @@ fn handle_end_of_line_comment_around_body<'a>(
     //     pass
     // ```
     if let Some(following) = comment.following_node() {
-        if is_first_statement_in_body(following, comment.enclosing_node())
+        if following.is_first_statement_in_body(comment.enclosing_node())
             && SimpleTokenizer::new(
                 locator.contents(),
                 TextRange::new(comment.end(), following.start()),
@@ -359,86 +378,6 @@ fn handle_end_of_line_comment_around_body<'a>(
     CommentPlacement::Default(comment)
 }
 
-/// Check if the given statement is the first statement after the colon of a branch, be it in if
-/// statements, for statements, after each part of a try-except-else-finally or function/class
-/// definitions.
-///
-///
-/// ```python
-/// if True:    <- has body
-///     a       <- first statement
-///     b
-/// elif b:     <- has body
-///     c       <- first statement
-///     d
-/// else:       <- has body
-///     e       <- first statement
-///     f
-///
-/// class:      <- has body
-///     a: int  <- first statement
-///     b: int
-///
-/// ```
-///
-/// For nodes with multiple bodies, we check all bodies that don't have their own node. For
-/// try-except-else-finally, each except branch has it's own node, so for the `StmtTry`, we check
-/// the `try:`, `else:` and `finally:`, bodies, while `ExceptHandlerExceptHandler` has it's own
-/// check. For for-else and while-else, we check both branches for the whole statement.
-///
-/// ```python
-/// try:        <- has body (a)
-///     6/8     <- first statement (a)
-///     1/0
-/// except:     <- has body (b)
-///     a       <- first statement (b)
-///     b
-/// else:
-///     c       <- first statement (a)
-///     d
-/// finally:
-///     e       <- first statement (a)
-///     f
-/// ```
-fn is_first_statement_in_body(statement: AnyNodeRef, has_body: AnyNodeRef) -> bool {
-    match has_body {
-        AnyNodeRef::StmtFor(ast::StmtFor { body, orelse, .. })
-        | AnyNodeRef::StmtWhile(ast::StmtWhile { body, orelse, .. }) => {
-            are_same_optional(statement, body.first())
-                || are_same_optional(statement, orelse.first())
-        }
-
-        AnyNodeRef::StmtTry(ast::StmtTry {
-            body,
-            orelse,
-            finalbody,
-            ..
-        }) => {
-            are_same_optional(statement, body.first())
-                || are_same_optional(statement, orelse.first())
-                || are_same_optional(statement, finalbody.first())
-        }
-
-        AnyNodeRef::StmtIf(ast::StmtIf { body, .. })
-        | AnyNodeRef::ElifElseClause(ast::ElifElseClause { body, .. })
-        | AnyNodeRef::StmtWith(ast::StmtWith { body, .. })
-        | AnyNodeRef::ExceptHandlerExceptHandler(ast::ExceptHandlerExceptHandler {
-            body, ..
-        })
-        | AnyNodeRef::MatchCase(MatchCase { body, .. })
-        | AnyNodeRef::StmtFunctionDef(ast::StmtFunctionDef { body, .. })
-        | AnyNodeRef::StmtClassDef(ast::StmtClassDef { body, .. }) => {
-            are_same_optional(statement, body.first())
-        }
-
-        AnyNodeRef::StmtMatch(ast::StmtMatch { cases, .. }) => {
-            are_same_optional(statement, cases.first())
-        }
-
-        _ => false,
-    }
-}
-
 /// Handles own-line comments around a body (at the end of the body, at the end of the header
 /// preceding the body, or between bodies):
 ///
@@ -590,13 +529,13 @@ fn handle_own_line_comment_between_branches<'a>(
     let Some(following) = comment.following_node() else {
         return CommentPlacement::Default(comment);
     };
-    if !is_first_statement_in_alternate_body(following, comment.enclosing_node()) {
+    if !following.is_first_statement_in_alternate_body(comment.enclosing_node()) {
         return CommentPlacement::Default(comment);
     }
 
     // It depends on the indentation level of the comment if it is a leading comment for the
     // following branch or if it a trailing comment of the previous body's last statement.
-    let comment_indentation = own_line_comment_indentation(preceding, &comment, locator);
+    let comment_indentation = comment_indentation_after(preceding, comment.range(), locator);
 
     let preceding_indentation = indentation(locator, &preceding)
         .unwrap_or_default()
@@ -680,7 +619,7 @@ fn handle_own_line_comment_after_branch<'a>(
 
     // We only care about the length because indentations with mixed spaces and tabs are only valid if
     // the indent-level doesn't depend on the tab width (the indent level must be the same if the tab width is 1 or 8).
-    let comment_indentation = own_line_comment_indentation(preceding, &comment, locator);
+    let comment_indentation = comment_indentation_after(preceding, comment.range(), locator);
 
     // Keep the comment on the entire statement in case it's a trailing comment
     // ```python
@@ -756,80 +695,6 @@ fn handle_own_line_comment_after_branch<'a>(
     }
 }
 
-/// Determine the indentation level of an own-line comment, defined as the minimum indentation of
-/// all comments between the preceding node and the comment, including the comment itself. In
-/// other words, we don't allow successive comments to ident _further_ than any preceding comments.
-///
-/// For example, given:
-/// ```python
-/// if True:
-///     pass
-///     # comment
-/// ```
-///
-/// The indentation would be 4, as the comment is indented by 4 spaces.
-///
-/// Given:
-/// ```python
-/// if True:
-///     pass
-/// # comment
-/// else:
-///     pass
-/// ```
-///
-/// The indentation would be 0, as the comment is not indented at all.
-///
-/// Given:
-/// ```python
-/// if True:
-///     pass
-///     # comment
-///         # comment
-/// ```
-///
-/// Both comments would be marked as indented at 4 spaces, as the indentation of the first comment
-/// is used for the second comment.
-///
-/// This logic avoids pathological cases like:
-/// ```python
-/// try:
-///     if True:
-///         if True:
-///             pass
-///
-///         # a
-///             # b
-///         # c
-/// except Exception:
-///     pass
-/// ```
-///
-/// If we don't use the minimum indentation of any preceding comments, we would mark `# b` as
-/// indented to the same depth as `pass`, which could in turn lead to us treating it as a trailing
-/// comment of `pass`, despite there being a comment between them that "resets" the indentation.
-fn own_line_comment_indentation(
-    preceding: AnyNodeRef,
-    comment: &DecoratedComment,
-    locator: &Locator,
-) -> TextSize {
-    let tokenizer = SimpleTokenizer::new(
-        locator.contents(),
-        TextRange::new(locator.full_line_end(preceding.end()), comment.end()),
-    );
-
-    tokenizer
-        .filter_map(|token| {
-            if token.kind() == SimpleTokenKind::Comment {
-                indentation_at_offset(token.start(), locator).map(TextLen::text_len)
-            } else {
-                None
-            }
-        })
-        .min()
-        .unwrap_or_default()
-}
-
 /// Attaches comments for the positional-only parameters separator `/` or the keywords-only
 /// parameters separator `*` as dangling comments to the enclosing [`Parameters`] node.
 ///
@@ -1488,10 +1353,10 @@ fn handle_attribute_comment<'a>(
 /// happens if the comments are in a weird position but it also doesn't hurt handling it.
 fn handle_expr_if_comment<'a>(
     comment: DecoratedComment<'a>,
-    expr_if: &'a ast::ExprIfExp,
+    expr_if: &'a ast::ExprIf,
     locator: &Locator,
 ) -> CommentPlacement<'a> {
-    let ast::ExprIfExp {
+    let ast::ExprIf {
         range: _,
         test,
         body,
@@ -1747,7 +1612,7 @@ fn handle_named_expr_comment<'a>(
     comment: DecoratedComment<'a>,
     locator: &Locator,
 ) -> CommentPlacement<'a> {
-    debug_assert!(comment.enclosing_node().is_expr_named_expr());
+    debug_assert!(comment.enclosing_node().is_expr_named());
 
     let (Some(target), Some(value)) = (comment.preceding_node(), comment.following_node()) else {
         return CommentPlacement::Default(comment);
@@ -2172,40 +2037,6 @@ fn handle_comprehension_comment<'a>(
     CommentPlacement::Default(comment)
 }
 
-/// Returns `true` if `right` is `Some` and `left` and `right` are referentially equal.
-fn are_same_optional<'a, T>(left: AnyNodeRef, right: Option<T>) -> bool
-where
-    T: Into<AnyNodeRef<'a>>,
-{
-    right.is_some_and(|right| left.ptr_eq(right.into()))
-}
-
-/// Returns `true` if `statement` is the first statement in an alternate `body` (e.g. the else of an if statement)
-fn is_first_statement_in_alternate_body(statement: AnyNodeRef, has_body: AnyNodeRef) -> bool {
-    match has_body {
-        AnyNodeRef::StmtFor(ast::StmtFor { orelse, .. })
-        | AnyNodeRef::StmtWhile(ast::StmtWhile { orelse, .. }) => {
-            are_same_optional(statement, orelse.first())
-        }
-
-        AnyNodeRef::StmtTry(ast::StmtTry {
-            handlers,
-            orelse,
-            finalbody,
-            ..
-        }) => {
-            are_same_optional(statement, handlers.first())
-                || are_same_optional(statement, orelse.first())
-                || are_same_optional(statement, finalbody.first())
-        }
-
-        AnyNodeRef::StmtIf(ast::StmtIf {
-            elif_else_clauses, ..
-        }) => are_same_optional(statement, elif_else_clauses.first()),
-        _ => false,
-    }
-}
-
 /// Returns `true` if the parameters are parenthesized (as in a function definition), or `false` if
 /// not (as in a lambda).
 fn are_parameters_parenthesized(parameters: &Parameters, contents: &str) -> bool {
