@@ -1,11 +1,10 @@
-use ruff_formatter::write;
 use ruff_formatter::FormatResult;
-use ruff_python_ast::node::AstNode;
+use ruff_python_ast::AstNode;
 use ruff_python_ast::TypeParams;
 use ruff_text_size::Ranged;
 
 use crate::builders::PyFormatterExtensions;
-use crate::comments::{trailing_comments, SourceComment};
+use crate::comments::SourceComment;
 use crate::expression::parentheses::parenthesized;
 use crate::prelude::*;
 
@@ -24,7 +23,6 @@ impl FormatNodeRule<TypeParams> for FormatTypeParams {
         // ] = ...
         let comments = f.context().comments().clone();
         let dangling_comments = comments.dangling(item.as_any_node_ref());
-        write!(f, [trailing_comments(dangling_comments)])?;
 
         let items = format_with(|f| {
             f.join_comma_separated(item.end())
@@ -32,7 +30,9 @@ impl FormatNodeRule<TypeParams> for FormatTypeParams {
                 .finish()
         });
 
-        parenthesized("[", &items, "]").fmt(f)
+        parenthesized("[", &items, "]")
+            .with_dangling_comments(dangling_comments)
+            .fmt(f)
     }
 
     fn fmt_dangling_comments(
